aboutsummaryrefslogtreecommitdiff
path: root/include/stem.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/stem.h')
-rw-r--r--include/stem.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/stem.h b/include/stem.h
index f252694..f4aff54 100644
--- a/include/stem.h
+++ b/include/stem.h
@@ -111,8 +111,8 @@ array_t *init_array(size_t size);
/*! appends element to back of array */
void array_append(array_t *a, value_t *v);
-/*! appends element to front of array */
-void array_curry(array_t *a, value_t *v);
+/*! add element to array at index */
+void array_add(array_t *a, value_t *v, int index);
/*! pops last element off of array */
value_t *array_pop(array_t *a);